@@ -1,4 +1,4 @@
-/* $Id: gucharmap-charmap.c 1300 2007-01-19 18:32:05Z chpe $ */
+/* $Id: gucharmap-charmap.c 1333 2007-04-30 18:55:55Z behdad $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -330,7 +330,7 @@ set_details (GucharmapCharmap *charmap,
   conditionally_insert_canonical_decomposition (charmap, buffer, &iter, uc);
 
   /* representations */
-  if (g_unichar_type(uc) != G_UNICODE_BREAK_SURROGATE)
+  if (g_unichar_break_type(uc) != G_UNICODE_BREAK_SURROGATE)
     {
       insert_heading (charmap, buffer, &iter, _("Various Useful Representations"));
 
